@@ -38,9 +38,5 @@ class ReadmangaMe(Provider, Std):
     def get_cover(self):
         return self._cover_from_content('.picture-fotorama > img')
 
-    def book_meta(self) -> dict:
-        # todo meta
-        pass
-
 
 main = ReadmangaMe
